@@ -137,8 +137,7 @@ sjp.corr <- function(data,
     # if yes, iterate each variable
     for (i in 1:ncol(data)) {
       # retrieve variable name attribute
-      vn <- sjmisc::get_label(data[[i]],
-                              def.value = get_var_name(deparse(substitute(data[[i]]))))
+      vn <- sjmisc::get_label(data[[i]], def.value = colnames(data)[i])
       # if variable has attribute, add to variableLabel list
       if (!is.null(vn)) {
         axisLabels <- c(axisLabels, vn)
@@ -319,7 +318,7 @@ sjp.corr <- function(data,
   # --------------------------------------------------------
   if (type == "circle") {
     corrPlot <- corrPlot +
-      geom_point(shape = 21, size = orderedCorr$psize, color = "black")
+      geom_point(shape = 21, size = orderedCorr$psize, colour = "black")
   }
   # --------------------------------------------------------
   # or boxes / tiles when "type" is "tile"
